SVG links open in new tab or window
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
`.Artist.set_url` allows to turn the Artist into a link. In SVG output,
this has been implemented without specifying a `target`_ attribute. The default
target value "_self" resulted in replacing the SVG document with the linked page
when the link was clicked.

The target is now set to "_blank" so that the link opens in a new tab or window.

.. _target: https://developer.mozilla.org/en-US/docs/Web/SVG/Reference/Attribute/target
